@@ -19,6 +19,7 @@ to avoid downloading and writing the same objects twice.
 
 import datetime
 import enum
+import glob
 import logging
 import os.path
 import re
@@ -152,6 +153,10 @@ class GitBareCooker(BaseVaultCooker):
         subprocess.run(["git", "-C", self.gitdir, "init", "--bare"], check=True)
         self.create_object_dirs()
 
+        # Remove example hooks; they take ~40KB and we don't use them
+        for filename in glob.glob(os.path.join(self.gitdir, "hooks", "*.sample")):
+            os.unlink(filename)
+
     def create_object_dirs(self) -> None:
         # Create all possible dirs ahead of time, so we don't have to check for
         # existence every time.
@@ -163,7 +168,10 @@ class GitBareCooker(BaseVaultCooker):
 
     def repack(self) -> None:
         # Add objects we wrote in a pack
-        subprocess.run(["git", "-C", self.gitdir, "repack", "-d"], check=True)
+        try:
+            subprocess.run(["git", "-C", self.gitdir, "repack", "-d"], check=True)
+        except subprocess.CalledProcessError:
+            logging.exception("git-repack failed with:")
 
         # Remove their non-packed originals
         subprocess.run(["git", "-C", self.gitdir, "prune-packed"], check=True)
@@ -185,10 +193,10 @@ class GitBareCooker(BaseVaultCooker):
 
         unexpected_errors = set(errors) - self._expected_fsck_errors
         if unexpected_errors:
-            raise Exception(
-                "\n".join(
-                    ["Unexpected errors from git-fsck:"] + sorted(unexpected_errors)
-                )
+            logging.error(
+                "Unexpected errors from git-fsck after cooking %s: %s",
+                self.swhid,
+                "\n".join(sorted(unexpected_errors)),
             )
 
     def write_refs(self, snapshot=None):
@@ -510,14 +518,15 @@ class GitBareCooker(BaseVaultCooker):
         self.write_object(obj_id, git_object)
 
         # Add children to the stack
-        entry_loaders: Dict[str, List[Sha1Git]] = {
+        entry_loaders: Dict[str, Optional[List[Sha1Git]]] = {
             "file": self._cnt_stack,
             "dir": self._dir_stack,
-            "rev": self._rev_stack,
+            "rev": None,  # Do not include submodule targets (rejected by git-fsck)
         }
         for entry in directory["entries"]:
             stack = entry_loaders[entry["type"]]
-            self._push(stack, [entry["target"]])
+            if stack is not None:
+                self._push(stack, [entry["target"]])
 
     def load_contents(self, obj_ids: List[Sha1Git]) -> None:
         # TODO: add support of filtered objects, somehow?
